@@ -2,9 +2,9 @@ package Model::Envoy;
 
 use MooseX::Role::Parameterized;
 use Module::Runtime 'use_module';
-use List::AllUtils 'first_result';
+use List::AllUtils qw( first first_result );
 
-our $VERSION = '0.5.0';
+our $VERSION = '0.5.1';
 
 =head1 Model::Envoy
 
@@ -187,7 +187,9 @@ Remove the instance from your persistent storage layer.
 
 =head3 dump()
 
-Provide an unblessed copy of the datastructure of your instance object.
+Provide an unblessed copy of the datastructure of your instance object. If any attributes are an instance of a Model::Envoy-using class (or an array of same),
+they will be recursively dumped. Other blessed objects will return undef unless they have a C<stringify> or C<to_string> method, in which case those will be
+used to represent the object.
 
 =head3 get_storage('Plugin')
 
@@ -411,6 +413,11 @@ sub _dump_property {
 
     return $value->dump if $value->can('does') && $value->does('Model::Envoy');
 
+    if ( my $method = first { $value->can($_) } qw( stringify to_string ) ) {
+
+        return $value->$method;
+    }
+
     return undef;
 }
 
